# Generated from the Telepathy spec
""" Copyright (C) 2005-2008 Collabora Limited 
 Copyright (C) 2005-2008 Nokia Corporation 
 Copyright (C) 2006 INdT 

This library is free software; you can redistribute it and/or
modify it under the terms of the GNU Lesser General Public
License as published by the Free Software Foundation; either
version 2.1 of the License, or (at your option) any later version.

This library is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
Lesser General Public License for more details.

You should have received a copy of the GNU Lesser General Public
License along with this library; if not, write to the Free Software
Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
  
"""

import dbus.service


class ChannelInterfaceHold(dbus.service.Interface):
    """\
      Interface for channels where you or other members may put
        the channel on hold. This only makes sense for channels where
        you are streaming media to or from the members.

      If you are placed on hold, this indicates that some or all members
        of the channel will no longer be receiving media streams from you.
        If the channel has the MediaSignalling interface, client applications
        should stop sending media to all members of the channel.

      Depending on the protocol, it might not be possible to tell that
        you're on hold, in which case the connection manager should always
        indicate that you're not on hold unless it finds out otherwise.

      If you place a channel on hold, this indicates that you do not wish
        to be sent media streams by any of its members and will be ignoring
        any media streams you continue to receive. It also requests that the
        connection manager free up any resources that are only needed for
        an actively used channel (e.g. in a GSM or PBX call, it will be
        necessary to place an active call on hold before you can start
        another call).
    """

    def __init__(self):
        self._interfaces.add('org.freedesktop.Telepathy.Channel.Interface.Hold')

    @dbus.service.method('org.freedesktop.Telepathy.Channel.Interface.Hold', in_signature='', out_signature='u')
    def GetHoldState(self):
        """
        Return the channel's current hold state.
      
        """
        raise NotImplementedError
  
    @dbus.service.method('org.freedesktop.Telepathy.Channel.Interface.Hold', in_signature='b', out_signature='')
    def RequestHold(self, hold):
        """
        Request that the channel be put on hold (be instructed not to send
        any media streams to you) or be taken off hold. Success is indicated
        by the HoldStateChanged signal being emitted and by a successful
        return from this method.
      
        """
        raise NotImplementedError
  
    @dbus.service.signal('org.freedesktop.Telepathy.Channel.Interface.Hold', signature='u')
    def HoldStateChanged(self, state):
        """
        Emitted to indicate that the hold state has changed for this channel.
        This may occur as a consequence of you requesting a change with
        RequestHold, or the state changing as a result of a request from a
        remote member or another process.
      
        """
        pass
  